#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const meow_1 = __importDefault(require("meow"));
const chalk_1 = __importDefault(require("chalk"));
const _1 = require(".");
const cli = meow_1.default(`
	Usage
	  $ graphql-schema-diff <schema1> <schema2>

  Options
    --fail-on-dangerous-changes  Exit with error on dangerous changes
    --ignore-breaking-changes  Do not exit with error on breaking changes

	Examples
	  $ graphql-schema-diff https://example.com/graphql schema.graphql
`, {
    flags: {
        'fail-on-dangerous-changes': {
            type: 'boolean'
        },
        'ignore-breaking-changes': {
            type: 'boolean'
        }
    }
});
if (!cli.input[0] || !cli.input[1]) {
    throw new Error('Schema locations missing!');
}
_1.getDiff(cli.input[0], cli.input[1]).then(result => {
    if (result === undefined) {
        console.log(chalk_1.default.green('✔ No changes'));
        return;
    }
    const hasBreakingChanges = () => result.breakingChanges.length !== 0;
    const hasDangerousChanges = () => result.dangerousChanges.length !== 0;
    console.log(result.diff);
    if (hasDangerousChanges) {
        console.log(chalk_1.default.yellow.bold.underline('Dangerous changes:'));
        for (const change of result.dangerousChanges) {
            console.log(chalk_1.default.yellow('  ⚠ ' + change.description));
        }
    }
    if (hasDangerousChanges && hasBreakingChanges) {
        console.log(); // Add additional line break
    }
    if (hasBreakingChanges) {
        console.log(chalk_1.default.red.bold.underline('BREAKING CHANGES:'));
        for (const change of result.breakingChanges) {
            console.log(chalk_1.default.red('  ✖ ' + change.description));
        }
    }
    if ((hasDangerousChanges && cli.flags.failOnDangerousChanges) ||
        (hasBreakingChanges && !cli.flags.ignoreBreakingChanges)) {
        process.exit(1);
        return;
    }
});
